SnapEdgeType enum

@name:slide_stop_type @package: @author:345 QQ:1831712732 @time:2023/03/30 10:25 @des:拖动后吸附在哪一侧

Inheritance
Available extensions

Values

snapEdgeLeft → const SnapEdgeType

吸附在左侧

snapEdgeRight → const SnapEdgeType

吸附在右侧

snapEdgeAuto → const SnapEdgeType

吸附在更近的一侧

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SnapEdgeType>
A constant List of the values in this enum, in order of their declaration.