FloatingEdgeType enum
@name:slide_enum @package: @author:345 QQ:1831712732 @time:2022/02/10 22:30 @des:悬浮窗坐标的起始点位置
Values
- onLeftAndTop → const FloatingEdgeType
-
左上
- onLeftAndBottom → const FloatingEdgeType
-
左下
- onRightAndTop → const FloatingEdgeType
-
右上
- onRightAndBottom → const FloatingEdgeType
-
右下
- onPoint → const FloatingEdgeType
-
根据 x,y 确定位置
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FloatingEdgeType> - A constant List of the values in this enum, in order of their declaration.