FloatingListenerController class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addFloatingListener(
FloatingEventListener listener) → void - 添加监听器(如果已存在则忽略)
-
clearListeners(
) → void - 清空所有监听器
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyClose(
) → void -
notifyHideFloating(
) → void -
notifyOpen(
) → void -
notifyShowFloating(
) → void -
notifyTouchDown(
FPosition< double> point) → void -
notifyTouchMove(
FPosition< double> point) → void -
notifyTouchMoveEnd(
FPosition< double> point) → void -
notifyTouchUp(
FPosition< double> point) → void -
removeFloatingListener(
FloatingEventListener listener) → bool - 移除监听器,返回是否移除成功
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited